@@ -3,10 +3,10 @@
 DEVICE_GROUP_CND = "com.telekom.iot.orchestrator.deviceGroup"
 
 # Type label name
-APPL_TYPE_LABEL_NAME = "type"
+APPL_TYPE_LABEL_NAME = "EndpointType"
 
 # Webhook application type 
-APPL_TYPE_WEBHOOK = "webHook"
+APPL_TYPE_WEBHOOK = "WebHook"
 
 # Default application type
 APPL_TYPE_DEFAULT = APPL_TYPE_WEBHOOK
