@@ -79,41 +79,63 @@ class Device(OneM2MBase):
 
     ### 
     # Device properties
-    def delete_device_properties(self):
-        old_labels = self.labels
-        new_labels = {}
-        for (k, v) in old_labels.items():
-            if k.startswith(UPLINK_PROPERTY_PREFIX) or k in DEVICE_SYSTEM_LABELS:
-                new_labels[k] = old_labels[k]
-        self.labels = new_labels
-
     def set_device_properties(self, props:dict):
-        if props == None:
-            return
+        self._set_prefixed_labels(DEVICE_PROPERTY_PREFIX, props)
+
+    def delete_device_properties(self):
+        self._delete_prefixed_labels(DEVICE_PROPERTY_PREFIX)
 
-        self.delete_device_properties()
-        
-        for (key, value) in props.items():
-            self._set_label(key, value)        
-            
     def set_device_property(self, key, value):
-        self._set_label(key, value)
-
+        self._set_prefixed_label(DEVICE_PROPERTY_PREFIX, key, value)
+        
     def del_device_property(self, key):
-        self._del_label(key)
+        self._del_perfixed_property(DEVICE_PROPERTY_PREFIX, key)
 
     @property    
-    def deviceProperties(self)->dict:
-        d = {}
-        for (k, v) in self.labels.items():
-            if k.startswith(UPLINK_PROPERTY_PREFIX) or k in DEVICE_SYSTEM_LABELS:
-                continue
-            d[k] = v
-        return d
+    def deviceProperties(self)->dict:   
+        return self._get_prefixed_labels(DEVICE_PROPERTY_PREFIX)
     
     @deviceProperties.setter
     def deviceProperties(self, props:dict):
-        self.set_device_properties(props)
+        self.set_device_properties(props)   
+
+    ### 
+    # Device properties
+    # def delete_device_properties(self):
+    #     old_labels = self.labels
+    #     new_labels = {}
+    #     for (k, v) in old_labels.items():
+    #         if k.startswith(UPLINK_PROPERTY_PREFIX) or k in DEVICE_SYSTEM_LABELS:
+    #             new_labels[k] = old_labels[k]
+    #     self.labels = new_labels
+
+    # def set_device_properties(self, props:dict):
+    #     if props == None:
+    #         return
+
+    #     self.delete_device_properties()
+        
+    #     for (key, value) in props.items():
+    #         self._set_label(key, value)        
+            
+    # def set_device_property(self, key, value):
+    #     self._set_label(key, value)
+
+    # def del_device_property(self, key):
+    #     self._del_label(key)
+
+    #@property    
+    # def deviceProperties(self)->dict:
+    #     d = {}
+    #     for (k, v) in self.labels.items():
+    #         if k.startswith(UPLINK_PROPERTY_PREFIX) or k in DEVICE_SYSTEM_LABELS:
+    #             continue
+    #         d[k] = v
+    #     return d
+    
+    # @deviceProperties.setter
+    # def deviceProperties(self, props:dict):
+    #     self.set_device_properties(props)
     
     ### DVI attributes
         
@@ -776,7 +798,7 @@ def create(api_client:ApiClient, # Client connection definition.
 
     if (props := kwargs.get("device_properties", None)):
         for (k, v) in props.items():
-            labels.append(f"{k}:{v}")
+            labels.append(f"{DEVICE_PROPERTY_PREFIX}{k}:{v}")
 
     if labels:
         labels.append(f"{d2c_consts.D2C_SYSTEM_VERSION_LABEL}:{d2c_consts.D2C_SYSTEM_VERSION}")
