@@ -78,7 +78,7 @@ def verify_application(api:ApiClient, name:str, props:dict):
     tutils.exec_test(f"Verifing {elem_path} for {elem_value}", operation)
 
     elem_path = "lbl"
-    elem_value = f'type:{props.get("type", APPL_TYPE_DEFAULT)}'
+    elem_value = f'{APPL_TYPE_LABEL_NAME}:{props.get("type", APPL_TYPE_DEFAULT)}'
     def operation():
         if not tutils.call_has_element_value(onem2m_dict, elem_path, elem_value):
             raise Exception(f"Value of element {elem_path} does not meet required value {elem_value}.")
