@@ -257,8 +257,9 @@ def verify_device(api: ApiClient, name:str, device_props:dict):
         
     for (key, val) in [["profile", DEVICE_PROFILES.SCS_LWM2M],
                         ["ICCID", device_props.get("iccid", None)],
-                        *[(k, v) for (k, v) in dev_props.items()],
-                        *[(f"UplinkProperty_{k}", v) for (k, v) in upl_props.items()]
+                        #*[(k, v) for (k, v) in dev_props.items()],
+                        *[(f"UplinkProperty_{k}", v) for (k, v) in upl_props.items()],
+                        *[(f"DeviceProperty_{k}", v) for (k, v) in dev_props.items()]                        
     ]:
         if val == None:
             continue
