@@ -276,7 +276,8 @@ class TestCase_AddApplicationsToDeviceGroup(TestCase):
         }
         '''
         device_group_name = self.cfg.get("name")
-        
+        device_group = DeviceGroup.get(api_client=self.api, name=device_group_name)
+
         ###
         # Verify if the application names have been added to the device group
         for application_name in self.application_names:
@@ -302,11 +303,14 @@ class TestCase_AddApplicationsToDeviceGroup(TestCase):
         for device_cfg in self.verify_device_cfgs:
             device_name = device_cfg.get("name")
 
-            # Name of subscription: <device-group-name>-<application-name>-<device-name>,
+            # Name of subscription: OLD: <device-group-name>-<application-name>-<device-name>,
+            #                       NEW: <device-group-id>-<application-id>                     
             for application_cfg in self.application_cfgs:
                 application_name = application_cfg.get("name")
-                
-                n = f"device-communication/{device_name}/received-msg/{device_group_name}-{application_name}-{device_name}"
+                application = Application.get(api_client=self.api, name=application_name)
+
+                # OLD: n = f"device-communication/{device_name}/received-msg/{device_group_name}-{application_name}-{device_name}"
+                n = f"device-communication/{device_name}/received-msg/{device_group.id}-{application.id}"
                 def operation():
                     onem2m_dict = dmo.get_resources(api_client=self.api, resourceType="subscription", resourceName=n)
                     if not onem2m_dict:
@@ -390,6 +394,7 @@ class TestCase_RemoveApplicationsFromDeviceGroup(TestCase):
         }
         '''
         name = self.cfg.get("name")
+        device_group = DeviceGroup.get(api_client=self.api, name=name)
         
         def operation():
             onem2m_dict = dmo.get_resources(api_client=self.api, resourceName=f"device-group/{name}")
@@ -414,11 +419,12 @@ class TestCase_RemoveApplicationsFromDeviceGroup(TestCase):
         for device_cfg in self.verify_device_cfgs:
             device_name = device_cfg.get("name")
 
-            # Name of subscription: <device-group-name>-<application-name>-<device-name>,
+            # Name of subscription: <device-group-id>-<application-id>
             for application_cfg in self.application_cfgs:
                 application_name = application_cfg.get("name")
+                application = Application.get(api_client=self.api, name=application_name)
                 
-                n = f"device-communication/{device_name}/received-msg/{name}-{application_name}-{device_name}"
+                n = f"device-communication/{device_name}/received-msg/{device_group.id}-{application.id}"
                 def operation():
                     onem2m_dict = dmo.get_resources(api_client=self.api, resourceType="subscription", resourceName=n)
                     if onem2m_dict:
@@ -506,6 +512,7 @@ class TestCase_AddDevicesToDeviceGroup(TestCase):
         }        
         '''
         device_group_name = self.cfg.get("name")
+        device_group = DeviceGroup.get(api_client=self.api, name=device_group_name)
 
         # Load device group
         def operation():
@@ -525,7 +532,8 @@ class TestCase_AddDevicesToDeviceGroup(TestCase):
             
         ###
         # Check the application subscription in the received message device communication container
-        # Name of subscription: <device-group-name>-<application-name>-<device-name>,
+        # Name of subscription: OLD: <device-group-name>-<application-name>-<device-name>,
+        #                       NEW: <device-group-id>-<application-id>                     
         if not self.verify_application_cfgs:
             return
         
@@ -534,8 +542,11 @@ class TestCase_AddDevicesToDeviceGroup(TestCase):
             
             for application_cfg in self.verify_application_cfgs:
                 application_name = application_cfg.get("name")
+                application = Application.get(api_client=self.api, name=application_name)
+                
+                # OLD: n = f"device-communication/{device_name}/received-msg/{device_group_name}-{application_name}-{device_name}"
+                n = f"device-communication/{device_name}/received-msg/{device_group.id}-{application.id}"
                 
-                n = f"device-communication/{device_name}/received-msg/{device_group_name}-{application_name}-{device_name}"
                 def operation():
                     onem2m_dict = dmo.get_resources(api_client=self.api, resourceType="subscription", resourceName=n)
                     if not onem2m_dict:
@@ -617,6 +628,7 @@ class TestCase_RemoveDevicesFromDeviceGroup(TestCase):
         }
         '''
         name = self.cfg.get("name")
+        device_group = DeviceGroup.get(api_client=self.api, name=name)
         
         def operation():
             onem2m_dict = dmo.get_resources(api_client=self.api, resourceName=f"device-group/{name}")
@@ -634,7 +646,7 @@ class TestCase_RemoveDevicesFromDeviceGroup(TestCase):
             
         ###
         # Check the application subscription in the received message device communication container
-        # Name of subscription: <device-group-name>-<application-name>-<device-name>,
+        # Name of subscription: <device-group-id>-<application-id>
         if not self.verify_application_cfgs:
             return
         
@@ -643,8 +655,9 @@ class TestCase_RemoveDevicesFromDeviceGroup(TestCase):
             
             for application_cfg in self.verify_application_cfgs:
                 application_name = application_cfg.get("name")
+                application = Application.get(api_client=self.api, name=application_name)
                 
-                n = f"device-communication/{device_name}/received-msg/{name}-{application_name}-{device_name}"
+                n = f"device-communication/{device_name}/received-msg/{device_group.id}-{application.id}"
                 def operation():
                     onem2m_dict = dmo.get_resources(api_client=self.api, resourceType="subscription", resourceName=n)
                     if onem2m_dict:
